| survobj-package | R Documentation |
Simulate parametric and semi-parametric survival times through a consistent, reusable interface for each distribution, using an object-oriented design. Supported distributions include Exponential, Weibull, Gompertz, Log-Logistic, Log-Normal, and Piecewise Exponential. Random variates can be generated under Proportional Hazards, Accelerated Failure Time, and Extended Hazards models, as well as under renewal and non-homogeneous Poisson recurrent event processes, following the methods described by Bender (2003) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.5282/UBM/EPUB.1716")} and Leemis (1987) in Operations Research, 35(6), 892-894.
Maintainer: Aponte John john.j.aponte@gmail.com (ORCID) [copyright holder]
Authors:
Aponte John john.j.aponte@gmail.com (ORCID) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.